/* This file stores the execution of the blink project, that allows to control the on-board LED from your Arduino board.
NOTE: On the UNO, MEGA and ZERO it is attached to digital pin 13, on MKR1000 on pin 6.
LED_BUILTIN is set to the correct LED pin independent of which board is used.

The following libraries are needed:
-. Arduino.h: includes Arduino specific commands for coding
-. wifi-mqtt.h: allows to connect to your WIFI and to the MQTT broker. Also allow for publish and subscribe from it.
-. delay.h: allows to get the delay value from the platform
-. Blink.h: stores the logic to make the on-board LED blink
-. SPI.h: This library allows you to communicate with SPI devices, with the Arduino as the master device.
-. ESP8266WiFi.h: This library i sused to connect ESP8266 WiFi module to the wifi
-. PubSubClient.h: A client library for MQTT messaging.
-. DHT.h: Arduino library for DHT11, DHT22, etc Temp & Humidity Sensors
-. humidity.h: stores the logic to get data from humidity sensor

Reference: arduino.cc
*/

#include <Arduino.h>
#include <wifi-mqtt.h>
#include <delay.h>
#include <blink.h>
#include <SPI.h>
#include <ESP8266WiFi.h>
#include <PubSubClient.h>
#include <DHT.h>
#include <humidity.h>


// setup function runs once when you press reset or power the board
void setup() {
  Serial.begin(9600); // Open serial communications
  wifi_mqtt_init(); // Initialize wifi connection and mqtt server
  mqtt_reconnect(); // Initialize MQTT connection
  init_delay(1000); //Set a default delay of 1000 miliseconds
  pinMode(LED_BUILTIN, OUTPUT); //Initialize LED_BUILTIN pin as an output pin  
}

// loop function runs over and over 
void loop() {

  turn_on(); //Turn the led on
  turn_off(); //Turn the led off

  humidity(); //humidity data
}





